pub struct CubicalComplex { /* private fields */ }Expand description
A cubical complex, stored as the cells of each dimension 0..=dim.
Implementations
Sourceimpl CubicalComplex
impl CubicalComplex
Sourcepub fn from_top_cells(top: Vec<Cube>) -> Self
pub fn from_top_cells(top: Vec<Cube>) -> Self
Build from filled top-dimensional cells, taking the downward closure (all faces of all faces).
Sourcepub fn progress(lengths: &[usize], forbidden: &[Vec<usize>]) -> Self
pub fn progress(lengths: &[usize], forbidden: &[Vec<usize>]) -> Self
The progress complex of d processes with the given step lengths: every grid d-cell is
filled, except those in forbidden (the mutual-exclusion / synchronization region).
pub fn dim(&self) -> usize
pub fn num_cells(&self, k: usize) -> usize